# Delightful Forgejo

[![delightful](https://codeberg.org/teaserbot-labs/delightful/raw/branch/main/assets/delightful-badge.svg)](https://codeberg.org/teaserbot-labs/delightful)

A curated list of delightful [Forgejo](https://forgejo.org/)-related projects and resources.

<!-- Everyone is invited to contribute. To do so, please read guidelines at: https://codeberg.org/teaserbot-labs/delightful -->


## Contents
- [Official resources](#official-resources)
- [Documentation](#documentation)
	- [Tutorials](#tutorials)
- [Public instances](#public-instances)
- [Packaging](#packaging)
- [Forgejo Actions](#forgejo-actions)
	- [Actions runners](#actions-runners)
	- [Actions runner deployment tools](#actions-runner-deployment-tools)
	- [Actions](#actions)
- [Clients](#clients)
	- [Mobile](#mobile)
	- [Command-line](#command-line)
- [Tools](#tools)
	- [Infrastructure as Code](#infrastructure-as-code)
	- [Monitoring](#monitoring)
	- [Bots](#bots)
	- [Scripts](#scripts)
	- [Package deployment](#package-deployment)
	- [API client libraries](#api-client-libraries)
- [References](#references)
- [Maintainers](#maintainers)
- [Contributors](#contributors)
- [License](#license)


Emoji for each entry provide additional information on project status:
- ![][forgejo] = official Forgejo resources
- 👻 = inactive for over a year, or officially abandoned
<!-- when adding unmaintained status to an entry, please move it to the end of its section of the list -->


## Official resources
Resources maintained as part of the primary Forgejo project.
- [![][forgejo] Forgejo website](https://forgejo.org/)
- [![][forgejo] Forgejo documentation](https://forgejo.org/docs/latest/)
- [![][forgejo] Forgejo issue tracker](https://codeberg.org/forgejo/forgejo)
- [![][forgejo] Forgejo releases](https://forgejo.org/releases) ([RSS feed](https://forgejo.org/releases/rss.xml); [Release notes](https://codeberg.org/forgejo/forgejo/src/branch/forgejo/RELEASE-NOTES.md))
- [![][forgejo] Forgejo runner](https://code.forgejo.org/forgejo/runner)
- [![][forgejo] Forgejo container images](https://codeberg.org/forgejo/-/packages/container/forgejo/versions)
- [![][forgejo] Forgejo Mastodon account](https://floss.social/@forgejo)
- [![][forgejo] Forgejo identity proofs (Keyoxide)](https://keyoxide.org/contact@forgejo.org)


## Documentation
In addition to [![][forgejo] Forgejo's official documentation](https://forgejo.org/docs/latest/), the following resources may be useful.

- [Codeberg documentation](https://docs.codeberg.org/) - contains some Codeberg-specific parts but is mostly applicable to every Forgejo instance.
- [Gitea documentation](https://docs.gitea.io/) - mostly applicable to Forgejo as well as Gitea.

### Tutorials
- [Setting up a Self-Hosted Forgejo Actions Runner with Docker Compose](https://linus.dev/posts/setting-up-a-self-hosted-forgejo-actions-runner-with-docker-compose/).
- [Forgejo in a nutshell](https://devforum.roblox.com/t/forgejo-in-a-nutshell/2505867) - guide to setup Forgejo.
- [Forgejo with LFS behind a VPN](https://blog.gibson.sh/2023/05/28/server-with-wireguard-and-forgejo/) - guide to set up a Linux web server running Forgejo, Git-LFS, and a Wireguard VPN.
- [UberLab installation guide](https://lab.uberspace.de/guide_forgejo/) - Forgejo installation guide for [Uberspace](https://uberspace.de/).


## Public instances
Forgejo instances with open registration.
- [Codeberg](https://codeberg.org) - free and open *for FOSS projects only*, run by a German non-profit organization. Also provides hosted Woodpecker (CI) and Weblate (localisation).
- [Disroot](https://disroot.org/en/services/git) - a platform providing online services based on principles of freedom, privacy, federation and decentralization. Also provides many other free hosted services.
- [pub.solar](https://git.pub.solar) - Register/Login via [pub.solar ID](https://auth.pub.solar), run by a German tech collective with the goal to enable more people to use free software, have secure digital communications, and to take control over their private data.
- [KaKi's git](https://git.kaki87.net) - free and open, run by a French web developer.


## Packaging
Platform-specific packages to easily install and update Forgejo on your system. These are generally maintained either by distro packagers or by community volunteers.

<a href="https://repology.org/project/forgejo/versions">
	<img src="https://repology.org/badge/vertical-allrepos/forgejo.svg" alt="Packaging status" align="right" />
</a>

Also see [forgejo package versions on Repology](https://repology.org/project/forgejo/versions).
- **Alpine**
	- [Alpine community `forgejo` package](https://pkgs.alpinelinux.org/packages?name=forgejo)
- **Arch Linux**
	- [Arch extra `forgejo` package](https://archlinux.org/packages/extra/x86_64/forgejo)
	- [AUR `forgejo-git` package](https://aur.archlinux.org/packages/forgejo-git)
- **Debian/Ubuntu**
	- [unofficial `forgejo-deb` packages + repo](https://codeberg.org/forgejo-contrib/forgejo-deb)
- **Fedora**
	- [RPM copr repo](https://copr.fedorainfracloud.org/coprs/nalika/gitea/)
- **FreeBSD**
	- [Port `www/forgejo` / package `forgejo`](https://www.freshports.org/www/forgejo) - binary packages available in latest and quarterly 2024Q2 or newer.
- **Gentoo**
	- [Gentoo GURU `www-apps/forgejo` package](https://gitweb.gentoo.org/repo/proj/guru.git/tree/www-apps/forgejo)
- **Kubernetes**
	- [Helm chart](https://codeberg.org/forgejo-contrib/forgejo-helm) - Helm chart for Forgejo, forked from the official Gitea helm chart
	- [c4k-forgejo](https://repo.prod.meissa.de/meissa/c4k-forgejo) - Convention 4 Kubernetes, generates a kubernetes manifest for Forgejo including backup & monitoring.
- **NixOS**
	- [NixOS master](https://github.com/NixOS/nixpkgs/blob/master/pkgs/applications/version-management/forgejo)
	- [NixOS unstable](https://github.com/NixOS/nixpkgs/blob/nixos-unstable/pkgs/applications/version-management/forgejo/default.nix)
- **Snapcraft** [![forgejo](https://snapcraft.io/forgejo/badge.svg)](https://snapcraft.io/forgejo)
	- [unofficial `forgejo` snap package](https://codeberg.org/forgejo-contrib/snap) - currently building in [launchpad](https://launchpad.net/~popey/forgejo-snap/+snap/forgejo-snap)
- **Termux (Android)**
    - [`forgejo` package](https://github.com/termux/termux-packages/tree/master/packages/forgejo)
- **Void Linux**
	- [unofficial `forgejo` package template](https://github.com/tranzystorekk/void-packages/tree/forgejo/srcpkgs/forgejo)
- **YunoHost**
	- [YunoHost package](https://github.com/YunoHost-Apps/forgejo_ynh) - install Forgejo quickly and simply on a YunoHost server
- **Cloudron**
	- [Cloudron package](https://codeberg.org/bart/forgejo-app) - Install Forgejo on a Cloudron server


## Forgejo Actions
Learn about Forgejo actions in the [![][forgejo] Actions admin guide](https://forgejo.org/docs/latest/admin/actions/) and [![][forgejo] Actions user guide](https://forgejo.org/docs/latest/user/actions/).

### Actions runners
- [![][forgejo] Forgejo runner](https://code.forgejo.org/forgejo/runner) - supports LXC & Docker & shell with binaries for GNU/Linux (amd64, arm64)
- [act runner](https://gitea.com/gitea/act_runner) - supports Docker & shell with binaries for GNU/Linux (amd64, arm64, arm[567]), FreeBSD, Windows, MacOS

### Actions runner deployment tools
- [forgejo-hetzner-runner](https://codeberg.org/pierreprinetti/forgejo-hetzner-runner) - Deploy Forgejo Actions runners on Hetzner infrastructure
- [helm-chart](https://codeberg.org/wrenix/helm-charts/src/branch/main/forgejo-runner) - Deploy a Forgejo Actions runner on the specified Forgejo instance

### Actions
- [trust-self-signed-cert](https://code.forgejo.org/Seltsamsel/trust-self-signed-cert) - Trust a self-signed SSL certificate for future operations (e.g. checkout action).


## Clients

### Mobile
- [GitNex](https://gitnex.com/) ([repo](https://codeberg.org/gitnex/GitNex)) - Android client for Forgejo and Gitea (`Android – GPL`)
- 👻 [GitTouch](https://github.com/git-touch/git-touch) - Mobile client for Forgejo, Gitea, GitHub, GitLab, Bitbucket (`Android, iOS – Apache`)

### Command-line
- [codeberg-cli](https://codeberg.org/Aviac/codeberg-cli) - CLI tool for Forgejo similar to `gh`, `glab` and `tea` (`cross-platform - AGPL`)
- [forgejo-cli](https://codeberg.org/Cyborus/forgejo-cli) - CLI tool for interacting with Forgejo (`cross-platform - Apache/MIT`)
- [![][forgejo] forgejo-curl](https://code.forgejo.org/forgejo/forgejo-curl) - a thin curl wrapper that helps with Forgejo authentication
- [tea](https://gitea.com/gitea/tea) - the official Gitea CLI client, works with Forgejo (`cross-platform – MIT`)


## Tools

### Infrastructure as Code
- [Ansible playbook](https://lab.enough.community/main/infrastructure/-/tree/master/playbooks/forgejo) - Deploy Forgejo & Woodpecker, depends on related [Enough Community](https://enough.community) playbooks.
- [Terraform & Ansible playbook](https://forgejo.dev/forgejo.dev/infrastructure-as-code/) - Deploy Forgejo, Minio, Nginx & Woodpecker in the cloud via [Docker Compose](https://docs.docker.com/compose/), depends on related [geerlingguy](https://github.com/geerlingguy) playbooks.

### Monitoring
- [Monitoring plugin to check Forgejo instance upgrade status](https://gitea.zionetrix.net/bn8/check_forgejo_upgrade) has the sources and is published in the [Icinga exchange repository](https://exchange.icinga.com/brenard/check_forgejo_upgrade).

### Bots
- [gitcat](https://git.mastodont.cat/spla/gitcat) - Python script that allows sign-up to a Forgejo instance to all local users of a Mastodon server. (`Python - GPLv3`)
- [Renovate](https://docs.renovatebot.com/modules/platform/gitea/#gitea-and-forgejo) - Dependency update tool (similar to dependabot) with Forgejo support. (`TypeScript - AGPLv3`)
- [Codeijika](https://codeberg.org/kita/codeijika) - A Discord bot that retrieves various information from a Forgejo instance like Codeberg. (`Python - AGPLv3`)

### Scripts
- [github2gitea/github2forgejo](https://github.com/maxkratz/github2gitea-mirror) - Bash script that creates mirrors for various GitHub resources like orgs, users and starred repos (incl. private repos). (`Bash - AGPLv3`)
- [Enhancements for Forgejo](https://git.kaki87.net/KaKi87/userscripts/src/branch/master/enhancementsForForgejo/README.md) - Violentmonkey userscript that adds minor UX improvements to the web UI. (`JavaScript - MIT`)

### Package deployment
- [lein-forgejo-wagon](https://codeberg.org/rome-user/lein-forgejo-wagon) - Leiningen plugin for deployment and downloading of JARs in Maven repositories hosted on Forgejo packages.

### API client libraries
- [Cyborus/forgejo-api](https://codeberg.org/Cyborus/forgejo-api) - Rust crate to interact with the Forgejo API (`Rust - Apache or MIT`)
- [harabat/pyforgejo](https://codeberg.org/harabat/pyforgejo) - Python client library to interact with the Forgejo API (`Python - MIT`)
- [mvdkleijn/forgejo-sdk](https://codeberg.org/mvdkleijn/forgejo-sdk) - Go client library to interact with the Forgejo API (fork of [gitea/go-sdk](https://gitea.com/gitea/go-sdk)) (`Go - MIT`)

## References
Noteworthy news, articles and information about Forgejo.

### Articles
- [Wikipedia DE](https://de.wikipedia.org/wiki/Forgejo)
- [Wikidata](https://www.wikidata.org/wiki/Q115962387)

### Videos
- [Brodie Robertson on the Open Letter](https://www.youtube.com/watch?v=Oc3cEfhpp08) - a 15-minute video about the Open Letter that led to the creation of Forgejo a few weeks later


## Maintainers

If you have questions or feedback regarding this list, then please create
an [Issue](https://codeberg.org/forgejo-contrib/delightful-forgejo/issues) in our tracker, and optionally `@mention` one or more of our maintainers:

- [`@caesar`](https://codeberg.org/caesar)
- [`@crystal`](https://codeberg.org/crystal)


## Contributors

With delight we present you some of our [delightful contributors](delightful-contributors.md) (please [add yourself](https://codeberg.org/teaserbot-labs/delightful/src/branch/master/delight-us.md#attribution-of-contributors) if you are missing).


## License

[![CC0](https://mirrors.creativecommons.org/presskit/buttons/88x31/svg/cc-zero.svg)](https://creativecommons.org/publicdomain/zero/1.0/)

To the extent possible under law, the [maintainers](#maintainers) and other [contributors](delightful-contributors.md) have waived all copyright and related or neighboring rights to this work.


[forgejo]: https://codeberg.org/forgejo-contrib/delightful-forgejo/media/branch/main/resources/forgejo-20.svg
